*******
Testing
*******

Built-in webserver
==================
Test your installation by connecting to built-in webserver. Run webserver::

    # su - noc
    $ cd /opt/noc/
    $ python manage.py runserver 0.0.0.0:8000

Builtin webserver is started at port 8000. Connect with your browser and enter
username and password set at :ref:`Initialize-Database` step.
